import React from 'react';
declare type BaseElement = HTMLDivElement;
declare type BaseProps = React.HTMLAttributes<BaseElement>;
export declare const TABLE_DIMENSIONS: {
    DEFAULT_MIN_COLUMN_WIDTH: number;
    PADDING_LEFT: number;
    PADDING: number;
    SELECT_WIDTH: number;
    MENU_WIDTH: number;
    ROW_HEIGHT: number;
};
/*******************************************************************************
 *
 * Column width control.
 *
 * The columns of a table always have a fixed width,
 * which is set initially either by the user or by
 * detecting the rendered size of the table, and dividing
 * it by the available columns. When you specify your
 * own initial widths, they will be scaled to the table
 * size automatically (and when resizing).
 *
 * The array of widths is updated using a reducer.
 *
 ******************************************************************************/
export declare enum WidthActionType {
    SET_WIDTHS = 0,
    UPDATE_WIDTHS = 1,
    RESET_WIDTHS = 2,
    SET_TOTAL_WIDTH = 3
}
interface ISetWidthsAction {
    readonly type: WidthActionType.SET_WIDTHS;
    readonly widths: ReadonlyArray<number>;
}
interface IUpdateWidthsAction {
    readonly type: WidthActionType.UPDATE_WIDTHS;
    readonly widths: {
        readonly [id: number]: number | undefined;
    };
    readonly onWidthsChange?: (widths: ReadonlyArray<number>) => void;
}
interface IResetWidthsAction {
    readonly type: WidthActionType.RESET_WIDTHS;
    readonly numberOfColumns: number;
}
interface ISetTotalWidthAction {
    readonly type: WidthActionType.SET_TOTAL_WIDTH;
    readonly value: number;
}
declare type WidthAction = ISetWidthsAction | IUpdateWidthsAction | IResetWidthsAction | ISetTotalWidthAction;
/*******************************************************************************
 *
 * TableContext
 *
 * Keeps track of table-wide properties which need to
 * be accessible from within each of the subcomponents.
 *
 ******************************************************************************/
export declare const TableContext: React.Context<{
    readonly minColumnWidth: number;
    readonly columnWidths: ReadonlyArray<number>;
    readonly dispatchWidthsAction: React.Dispatch<WidthAction>;
    readonly selectWidth: number;
    readonly menuWidth: number;
    readonly onSelect?: ((selected: boolean, id?: string | undefined) => void) | undefined;
    readonly hasMenu: boolean;
    readonly onWidthsChange?: ((widths: ReadonlyArray<number>) => void) | undefined;
}>;
/**
 * Transform the array of widths to an appropriate grid-template-columns
 * string, taking into account select/menu columns.
 *
 * Example:
 *  [34, 78]
 */
export declare const useGridTemplateColumns: () => {
    gridTemplateColumns: string;
};
/**
 * Table
 *
 * Defined by the number of columns.
 */
interface ITableProps extends Omit<BaseProps, 'onSelect'> {
    /**
     * `class` to be passed to the component.
     */
    readonly className?: BaseProps['className'];
    /**
     * The initial widths for the columns of the Table.
     * The width will be automatically adjusted to fit the
     * table, so use 0 if not known, e.g. new Array(#columns).fill(0)
     * would be a valid starting point.
     */
    readonly initialWidths?: ReadonlyArray<number>;
    /**
     * Control if columns should be resizeable or not. If true, resize
     * handles will be available to change column width.
     *
     * @default false
     */
    readonly resizableColumns?: boolean;
    /**
     * Minimum column width.
     *
     * @default DEFAULT_MIN_COLUMN_WIDTH
     */
    readonly minColumnWidth?: number;
    /**
     * Callback which will get the (new) array of column widths
     * every time any width is changed.
     */
    readonly onWidthsChange?: (widths: ReadonlyArray<number>) => void;
    /**
     * The maximum height of the table in number of rows,
     * more rows will cause a scrollbar to appear.
     */
    readonly maxHeight?: number;
    /**
     * Callback which will get checked status and row ID on selection.
     * The ID is undefined if the main checkbox is selected ("select all").
     */
    readonly onSelect?: (selected: boolean, id?: string) => void;
    /**
     * Allow for optional right-side menu content for each row.
     */
    readonly hasMenu?: boolean;
    /**
     * Key to control scrollbar in Table.
     * If key changes, scrollbar will scroll to top.
     */
    readonly scrollKey?: string;
}
export declare const Table: React.FunctionComponent<ITableProps>;
export {};
